Extract the coefficient vector from a quantile regression model object
Source:R/utils-factors.R
extract_coefficients.RdReturns the flat coefficient vector regardless of whether the model was fitted with conquer::conquer ($coeff) or quantreg::rq ($coefficients).