Truncated reconstruction from scores and loadings
Source:R/utils-factors.R
reconstruct_scores_loadings.RdHelper function to compute fitted values from the first n.comp components.

R/utils-factors.R
reconstruct_scores_loadings.RdHelper function to compute fitted values from the first n.comp components.