Split points of a given matrix Y into train / test
Source:R/utils-split.R
train_test_split_points.RdSplit points of a given matrix Y into train / test based on parameters train.pct and train.size. If both are informed train.pct takes preference. This function keeps the dimensions of the original Y in both train and test and substitutes the values in both splits by NAs